@@ -4,12 +4,14 @@
 from __future__ import (absolute_import, division, print_function)
 
 __metaclass__ = type
-__requires__ = ['ansible_core']
 
 
+import argparse
 import fcntl
 import hashlib
+import io
 import os
+import pickle
 import signal
 import socket
 import sys
@@ -21,9 +23,8 @@ import json
 from contextlib import contextmanager
 
 from ansible import constants as C
+from ansible.cli.arguments.option_helpers import AnsibleVersion
 from ansible.module_utils._text import to_bytes, to_text
-from ansible.module_utils.six import PY3
-from ansible.module_utils.six.moves import cPickle, StringIO
 from ansible.module_utils.connection import Connection, ConnectionError, send_data, recv_data
 from ansible.module_utils.service import fork_process
 from ansible.parsing.ajson import AnsibleJSONEncoder, AnsibleJSONDecoder
@@ -33,6 +34,8 @@ from ansible.utils.path import unfrackpath, makedirs_safe
 from ansible.utils.display import Display
 from ansible.utils.jsonrpc import JsonRpcServer
 
+display = Display()
+
 
 def read_stream(byte_stream):
     size = int(byte_stream.readline().strip())
@@ -86,11 +89,11 @@ class ConnectionProcess(object):
         self.connection = None
         self._ansible_playbook_pid = ansible_playbook_pid
 
-    def start(self, variables):
-        try:
-            messages = list()
-            result = {}
+    def start(self, options):
+        messages = list()
+        result = {}
 
+        try:
             messages.append(('vvvv', 'control socket path is %s' % self.socket_path))
 
             # If this is a relative path (~ gets expanded later) then plug the
@@ -101,7 +104,7 @@ class ConnectionProcess(object):
             self.connection = connection_loader.get(self.play_context.connection, self.play_context, '/dev/null',
                                                     task_uuid=self._task_uuid, ansible_playbook_pid=self._ansible_playbook_pid)
             try:
-                self.connection.set_options(var_options=variables)
+                self.connection.set_options(direct=options)
             except ConnectionError as exc:
                 messages.append(('debug', to_text(exc)))
                 raise ConnectionError('Unable to decode JSON from response set_options. See the debug log for more information.')
@@ -125,6 +128,7 @@ class ConnectionProcess(object):
 
     def run(self):
         try:
+            log_messages = self.connection.get_option('persistent_log_messages')
             while not self.connection._conn_closed:
                 signal.signal(signal.SIGALRM, self.connect_timeout)
                 signal.signal(signal.SIGTERM, self.handler)
@@ -138,7 +142,6 @@ class ConnectionProcess(object):
                     data = recv_data(s)
                     if not data:
                         break
-                    log_messages = self.connection.get_option('persistent_log_messages')
 
                     if log_messages:
                         display.display("jsonrpc request: %s" % data, log_only=True)
@@ -218,35 +221,34 @@ class ConnectionProcess(object):
         display.display('shutdown complete', log_only=True)
 
 
-def main():
+def main(args=None):
     """ Called to initiate the connect to the remote device
     """
+    parser = argparse.ArgumentParser(prog='ansible-connection', add_help=False)
+    parser.add_argument('--version', action=AnsibleVersion, nargs=0)
+    parser.add_argument('playbook_pid')
+    parser.add_argument('task_uuid')
+    args = parser.parse_args(args[1:] if args is not None else args)
+
     rc = 0
     result = {}
     messages = list()
     socket_path = None
 
     # Need stdin as a byte stream
-    if PY3:
-        stdin = sys.stdin.buffer
-    else:
-        stdin = sys.stdin
+    stdin = sys.stdin.buffer
 
     # Note: update the below log capture code after Display.display() is refactored.
     saved_stdout = sys.stdout
-    sys.stdout = StringIO()
+    sys.stdout = io.StringIO()
 
     try:
         # read the play context data via stdin, which means depickling it
-        vars_data = read_stream(stdin)
+        opts_data = read_stream(stdin)
         init_data = read_stream(stdin)
 
-        if PY3:
-            pc_data = cPickle.loads(init_data, encoding='bytes')
-            variables = cPickle.loads(vars_data, encoding='bytes')
-        else:
-            pc_data = cPickle.loads(init_data)
-            variables = cPickle.loads(vars_data)
+        pc_data = pickle.loads(init_data, encoding='bytes')
+        options = pickle.loads(opts_data, encoding='bytes')
 
         play_context = PlayContext()
         play_context.deserialize(pc_data)
@@ -261,8 +263,8 @@ def main():
 
     if rc == 0:
         ssh = connection_loader.get('ssh', class_only=True)
-        ansible_playbook_pid = sys.argv[1]
-        task_uuid = sys.argv[2]
+        ansible_playbook_pid = args.playbook_pid
+        task_uuid = args.task_uuid
         cp = ssh._create_control_path(play_context.remote_addr, play_context.port, play_context.remote_user, play_context.connection, ansible_playbook_pid)
         # create the persistent connection dir if need be and create the paths
         # which we will be using later
@@ -284,7 +286,7 @@ def main():
                         os.close(r)
                         wfd = os.fdopen(w, 'w')
                         process = ConnectionProcess(wfd, play_context, socket_path, original_path, task_uuid, ansible_playbook_pid)
-                        process.start(variables)
+                        process.start(options)
                     except Exception:
                         messages.append(('error', traceback.format_exc()))
                         rc = 1
@@ -307,7 +309,7 @@ def main():
                 messages.append(('vvvv', 'found existing local domain socket, using it!'))
                 conn = Connection(socket_path)
                 try:
-                    conn.set_options(var_options=variables)
+                    conn.set_options(direct=options)
                 except ConnectionError as exc:
                     messages.append(('debug', to_text(exc)))
                     raise ConnectionError('Unable to decode JSON from response set_options. See the debug log for more information.')
@@ -346,5 +348,4 @@ def main():
 
 
 if __name__ == '__main__':
-    display = Display()
     main()
